"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.functionSchematic = exports.functionGenerator = exports.normalizeOptions = void 0;
const tslib_1 = require("tslib");
const devkit_1 = require("@nx/devkit");
const node_1 = require("@nx/node");
const init_1 = require("../init/init");
const utils_1 = require("../../utils");
const lib_1 = require("./lib");
const project_name_and_root_utils_1 = require("@nx/devkit/src/generators/project-name-and-root-utils");
const nx_firebase_versions_1 = require("../../__generated__/nx-firebase-versions");
function normalizeOptions(host, options, callingGenerator = '@simondotm/nx-firebase:function') {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const { projectName: appProjectName, projectRoot, projectNameAndRootFormat, } = yield (0, project_name_and_root_utils_1.determineProjectNameAndRootOptions)(host, {
            name: options.name,
            projectType: 'application',
            directory: options.directory,
            projectNameAndRootFormat: options.projectNameAndRootFormat,
            rootProject: options.rootProject,
            callingGenerator,
        });
        options.rootProject = projectRoot === '.';
        options.projectNameAndRootFormat = projectNameAndRootFormat;
        const parsedTags = options.tags
            ? options.tags.split(',').map((s) => s.trim())
            : [];
        // const { projectName, projectRoot } = getProjectName(
        //   host,
        //   options.name,
        //   options.directory,
        // )
        // get & validate the firebase app project this function will be attached to
        const firebaseApp = (0, devkit_1.names)(options.app).fileName;
        const projects = (0, devkit_1.getProjects)(host);
        if (!projects.has(firebaseApp)) {
            throw new Error(`A firebase application project called '${firebaseApp}' was not found in this workspace.`);
        }
        const firebaseAppProject = (0, devkit_1.readProjectConfiguration)(host, firebaseApp);
        // read the firebase config used by the parent app project
        const firebaseConfigName = (0, utils_1.getFirebaseConfigFromProject)(host, firebaseAppProject);
        return Object.assign(Object.assign({}, options), { name: (0, devkit_1.names)(options.name).fileName, projectName: appProjectName, projectRoot,
            parsedTags,
            firebaseConfigName,
            firebaseAppProject });
        // return {
        //   ...options,
        //   runTime: options.runTime || '16',
        //   format: options.format || 'esm',
        //   projectRoot,
        //   projectName,
        //   firebaseConfigName,
        //   firebaseAppProject,
        // }
    });
}
exports.normalizeOptions = normalizeOptions;
/**
 * Firebase 'functions' application generator
 * Uses the `@nx/node` application generator as a base implementation
 *
 * @param host
 * @param schema
 * @returns
 */
function functionGenerator(host, schema) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const tasks = [];
        const options = yield normalizeOptions(host, Object.assign({ 
            // set default options
            projectNameAndRootFormat: 'derived', runTime: nx_firebase_versions_1.packageVersions.nodeEngine }, schema));
        if (!options.runTime) {
            throw new Error('No runtime specified for the function app');
        }
        // const options = normalizeOptions(host, schema)
        // initialise plugin
        const initTask = yield (0, init_1.initGenerator)(host, {});
        tasks.push(initTask);
        // We use @nx/node:app to scaffold our function application, then modify as required
        // `nx g @nx/node:app function-name --directory functions/dir --e2eTestRunner=none --framework=none --unitTestRunner=jest --bundler=esbuild --tags=firebase:firebase-app`
        // Function apps are tagged so that they can built/watched with run-many
        const tags = `firebase:function,firebase:name:${options.projectName},firebase:dep:${options.firebaseAppProject.name}` +
            (options.tags ? `,${options.tags}` : '');
        const nodeApplicationTask = yield (0, node_1.applicationGenerator)(host, {
            name: options.name,
            directory: options.directory,
            projectNameAndRootFormat: options.projectNameAndRootFormat,
            tags,
            setParserOptionsProject: options.setParserOptionsProject,
            skipFormat: options.skipFormat,
            e2eTestRunner: 'none',
            bundler: 'esbuild',
            framework: 'none',
            unitTestRunner: 'jest',
        });
        tasks.push(nodeApplicationTask);
        // generate function app specific files
        (0, lib_1.createFiles)(host, options);
        // update TS config for esm or cjs
        (0, utils_1.updateTsConfig)(host, options.projectRoot, options.runTime, options.format);
        // reconfigure the @nx/node:app to suit firebase functions
        (0, lib_1.updateProject)(host, options);
        // update firebase functions config
        (0, lib_1.addFunctionConfig)(host, options);
        // ensures newly added files are formatted to match workspace style
        if (!options.skipFormat) {
            yield (0, devkit_1.formatFiles)(host);
        }
        return (0, devkit_1.runTasksInSerial)(...tasks);
    });
}
exports.functionGenerator = functionGenerator;
exports.default = functionGenerator;
exports.functionSchematic = (0, devkit_1.convertNxGenerator)(functionGenerator);
//# sourceMappingURL=function.js.map