"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createFiles = void 0;
const devkit_1 = require("@nx/devkit");
const nx_firebase_versions_1 = require("../../../__generated__/nx-firebase-versions");
/**
 * Generate the firebase app specific files
 *
 * @param host
 * @param options
 */
function createFiles(host, options) {
    const firebaseAppConfig = options.firebaseConfigName;
    const firebaseAppConfigPath = (0, devkit_1.joinPathFragments)((0, devkit_1.offsetFromRoot)(options.projectRoot), firebaseAppConfig);
    const substitutions = {
        tmpl: '',
        projectName: options.projectName,
        projectRoot: options.projectRoot,
        firebaseAppName: options.app,
        firebaseAppConfig,
        firebaseAppConfigPath,
        firebaseNodeEngine: options.runTime,
        // firebaseNodeRuntime,
        // firebaseNodeEngine,
        moduleType: options.format === 'esm' ? 'module' : 'commonjs',
    };
    // The default functions package.json & templated typescript source files are added here
    // to match the `firebase init` cli setup
    // if the user isn't using functions, they can just delete and update their firebase config accordingly
    //
    // Rules and index files also get generated in the application folder;
    // 1. so that they dont clutter up the root workspace
    // 2. so that they are located within the nx firebase application project they relate to
    (0, devkit_1.generateFiles)(host, (0, devkit_1.joinPathFragments)(__dirname, '..', 'files'), options.projectRoot, substitutions);
    // set dependencies for the firebase function
    const firebasePackageDependencies = {};
    if ((0, devkit_1.detectPackageManager)() === 'pnpm') {
        firebasePackageDependencies['@google-cloud/functions-framework'] = `^${nx_firebase_versions_1.packageVersions.googleCloudFunctionsFramework}`;
    }
    if (Object.keys(firebasePackageDependencies).length > 0) {
        (0, devkit_1.updateJson)(host, (0, devkit_1.joinPathFragments)(options.projectRoot, 'package.json'), (json) => {
            json.dependencies = firebasePackageDependencies;
            return json;
        });
    }
}
exports.createFiles = createFiles;
//# sourceMappingURL=create-files.js.map