"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.addDependencies = void 0;
const devkit_1 = require("@nx/devkit");
const utils_1 = require("../../../utils");
const nx_firebase_versions_1 = require("../../../__generated__/nx-firebase-versions");
function addDependencies(tree) {
    const dependencies = {};
    const devDependencies = {};
    // SM: only add firebase related dependencies if they do not already exist
    // This is atypical for Nx plugins that usually migrate versions automatically
    //  however the nx-firebase plugin is not (currently) opinionated about which version is needed,
    //  so this ensures workspaces retain control over their firebase versions.
    const packageJson = (0, devkit_1.readJson)(tree, 'package.json');
    function addDependencyIfNotPresent(packageName, packageVersion) {
        if (!packageJson.dependencies || !packageJson.dependencies[packageName]) {
            dependencies[packageName] = packageVersion;
            return true;
        }
        return false;
    }
    function addDevDependencyIfNotPresent(packageName, packageVersion) {
        if (!packageJson.devDependencies ||
            !packageJson.devDependencies[packageName]) {
            devDependencies[packageName] = packageVersion;
            return true;
        }
        return false;
    }
    // Firebase packages are not managed by the plugin
    // but they are added if they do not exist already in the workspace
    addDependencyIfNotPresent('firebase', `^${nx_firebase_versions_1.packageVersions.firebase}`);
    addDependencyIfNotPresent('firebase-admin', `^${nx_firebase_versions_1.packageVersions.firebaseAdmin}`);
    addDependencyIfNotPresent('firebase-functions', `^${nx_firebase_versions_1.packageVersions.firebaseFunctions}`);
    // if the workspace uses pnpm, we need to add the @google-cloud/functions-framework package
    if ((0, devkit_1.detectPackageManager)() === 'pnpm') {
        if (addDependencyIfNotPresent('@google-cloud/functions-framework', `^${nx_firebase_versions_1.packageVersions.googleCloudFunctionsFramework}`)) {
            devkit_1.logger.info(`This workspace is using pnpm, adding '@google-cloud/functions-framework' dependency for firebase functions compatibility\nSee https://github.com/firebase/firebase-tools/issues/5911#issuecomment-1730263400\n\n`);
        }
    }
    // firebase dev dependencies
    addDevDependencyIfNotPresent('firebase-tools', `^${nx_firebase_versions_1.packageVersions.firebaseTools}`);
    addDevDependencyIfNotPresent('firebase-functions-test', `^${nx_firebase_versions_1.packageVersions.firebaseFunctionsTest}`);
    // kill-port is used by the emulate target to ensure clean emulator startup
    // since Nx doesn't kill processes cleanly atm
    addDevDependencyIfNotPresent('kill-port', `^${nx_firebase_versions_1.packageVersions.killPort}`);
    // @nx/node is used by the plugin function generator as a proxy for creating a typescript app
    // since users have to create a firebase app before they generate a function, we can be sure
    // this plugin init will have been run before the function generator that requires @nx/node is used
    // we defer to @nx/node to install its own plugins such as @nx/eslint, @nx/jest, @nx/js, @nx/esbuild, @nx/webpack etc.
    addDevDependencyIfNotPresent('@nx/node', utils_1.workspaceNxVersion.version);
    return (0, devkit_1.addDependenciesToPackageJson)(tree, dependencies, devDependencies);
}
exports.addDependencies = addDependencies;
//# sourceMappingURL=add-dependencies.js.map