"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getFirebaseConfigs = void 0;
const devkit_1 = require("@nx/devkit");
const utils_1 = require("../../../utils");
const types_1 = require("../../../types");
const FIREBASE_CONFIG_FILE_MATCHER = /(firebase)(\S*)(.json)/;
function getFirebaseConfigs(tree, projects) {
    const firebaseConfigs = new Map();
    const firebaseAppConfigs = new Map();
    const firebaseConfigProjects = new Map();
    (0, utils_1.debugInfo)(`- firebaseAppProjects=${(0, utils_1.mapKeys)(projects.firebaseAppProjects)}`);
    (0, utils_1.debugInfo)(`- firebaseFunctionProjects=${(0, utils_1.mapKeys)(projects.firebaseFunctionProjects)}`);
    // collect all firebase[.*].json config files in workspace
    const rootFiles = tree.children('');
    rootFiles.map((child) => {
        if (tree.isFile(child)) {
            if (child.match(FIREBASE_CONFIG_FILE_MATCHER)) {
                firebaseConfigs.set(child, (0, devkit_1.readJson)(tree, child));
                // set an firebaseConfigProjects as null for now, later we will add the project
                firebaseConfigProjects.set(child, types_1.CONFIG_NO_APP);
            }
        }
    });
    (0, utils_1.debugInfo)(`- firebaseConfigs=${(0, utils_1.mapKeys)(firebaseConfigs)}`);
    // map firebase configs to their apps
    // we do this by reading the --config setting directly from each firebase app's firebase target
    // this is more robust & flexible than using filename assumptions for configs
    // it also means users can freely rename their firebase configs and the plugin will work
    projects.firebaseAppProjects.forEach((project, name) => {
        const firebaseTarget = project.targets.firebase;
        if (!firebaseTarget) {
            throw new Error(`Firebase app project ${name} does not have a 'firebase' target. Sync will no longer work.`);
        }
        const firebaseConfigName = (0, utils_1.getFirebaseConfigFromProject)(tree, project);
        firebaseAppConfigs.set(name, firebaseConfigName);
        firebaseConfigProjects.set(firebaseConfigName, name);
        // bit opinionated, but we need to sanity check that
        // production configurations on this target use the same config file.
        // since we cant rename configs safely with this scenario
        // different build configs should only differ in --project
        const configurations = firebaseTarget.configurations;
        for (const configuration in configurations) {
            const additionalConfigName = (0, utils_1.getFirebaseConfigFromCommand)(tree, project, configurations[configuration].command);
            if (additionalConfigName !== firebaseConfigName) {
                throw new Error(`Firebase app project ${name} target firebase.configurations.${configuration} has a different --config setting which is unsupported by this plugin.`);
            }
        }
    });
    (0, utils_1.debugInfo)(`- firebaseAppConfigs=${(0, utils_1.mapEntries)(firebaseAppConfigs)}`);
    (0, utils_1.debugInfo)(`- firebaseConfigProjects=${(0, utils_1.mapEntries)(firebaseConfigProjects)},
    )}`);
    return {
        firebaseConfigs,
        firebaseAppConfigs,
        firebaseConfigProjects,
    };
}
exports.getFirebaseConfigs = getFirebaseConfigs;
//# sourceMappingURL=firebase-configs.js.map