"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.updateFirebaseAppDeployProject = exports.getFirebaseProjects = exports.isFirebaseFunction = exports.isFirebaseApp = void 0;
const devkit_1 = require("@nx/devkit");
const debug_1 = require("../../../utils/debug");
const FIREBASE_PROJECT_MATCHER = /(--project[ =])([^\s]+)/;
const FIREBASE_COMMAND_MATCHER = /(firebase)/;
function isFirebaseApp(project) {
    var _a;
    return (_a = project.tags) === null || _a === void 0 ? void 0 : _a.includes('firebase:app');
}
exports.isFirebaseApp = isFirebaseApp;
function isFirebaseFunction(project) {
    var _a;
    return (_a = project.tags) === null || _a === void 0 ? void 0 : _a.includes('firebase:function');
}
exports.isFirebaseFunction = isFirebaseFunction;
/**
 * Scan the workspace, identifying firebase projects managed by this plugin by their tags:
 * - firebase:app
 * - firebase:function
 * @param tree - host workspace
 * @returns FirebaseProjects object
 */
function getFirebaseProjects(tree) {
    const projects = (0, devkit_1.getProjects)(tree);
    const firebaseAppProjects = new Map();
    const firebaseFunctionProjects = new Map();
    (0, debug_1.debugInfo)('- building list of firebase apps & functions');
    projects.forEach((project, projectName) => {
        if (isFirebaseApp(project)) {
            firebaseAppProjects.set(projectName, project);
        }
        if (isFirebaseFunction(project)) {
            firebaseFunctionProjects.set(projectName, project);
        }
    });
    return {
        firebaseAppProjects,
        firebaseFunctionProjects,
    };
}
exports.getFirebaseProjects = getFirebaseProjects;
/**
 * Rewrite the firebase deploy command for the given function deploy target
 *  to either add or update the --project cli parameter
 * @param target - deploy target in the function
 * @param options -
 */
function updateFirebaseAppDeployProject(target, options) {
    const command = target.options.command;
    if (command.includes('firebase')) {
        (0, debug_1.debugInfo)('- found firebase target command');
        (0, debug_1.debugInfo)(`- command=${command}`);
        if (command.includes('--project')) {
            (0, debug_1.debugInfo)('- found --project in firebase target command');
            // already set, so update
            target.options.command = command.replace(FIREBASE_PROJECT_MATCHER, '$1' + options.project);
            (0, debug_1.debugInfo)(`- new command: ${target.options.command}`);
            devkit_1.logger.info(`CHANGE updating firebase target --project for '${options.app}' to '--project=${options.project}'`);
            return true;
        }
        else {
            (0, debug_1.debugInfo)('- did not find --project in deploy command');
            // no set, so add
            target.options.command = command.replace(FIREBASE_COMMAND_MATCHER, '$1' + ' ' + `--project=${options.project}`);
            (0, debug_1.debugInfo)(`- new command: ${target.options.command}`);
            devkit_1.logger.info(`CHANGE setting firebase target --project for '${options.app}' to '--project=${options.project}'`);
            return true;
        }
    }
    return false;
}
exports.updateFirebaseAppDeployProject = updateFirebaseAppDeployProject;
//# sourceMappingURL=firebase-projects.js.map