"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.updateFirebaseProjectNameTag = exports.getFirebaseScopeFromTag = void 0;
const devkit_1 = require("@nx/devkit");
const debug_1 = require("../../../utils/debug");
/**
 * Parse a firebase tag value for the given scope
 * Expected to find tag of format: `firebase:name:<projectname>` or `firebase:dep:<appname>`
 * @param project - Project to be checked
 * @param scope - `firebase:name` or `firebase:dep`
 * @returns value part of tag
 * @throws if requested tag is missing, or malformed
 */
function getFirebaseScopeFromTag(project, scope) {
    const tags = project.tags;
    if (tags) {
        for (let i = 0; i < tags.length; ++i) {
            const tag = tags[i];
            (0, debug_1.debugInfo)(`- checking tag '${tag}' for scope '${scope}'`);
            if (tag.includes(scope)) {
                (0, debug_1.debugInfo)(`- matched tag '${tag}' for scope '${scope}'`);
                const scopes = tag.split(':');
                if (scopes.length === 3) {
                    (0, debug_1.debugInfo)(`- returning tagValue '${scopes[2]}' tagIndex '${i}'`);
                    return { tagValue: scopes[2], tagIndex: i };
                }
                else {
                    throw new Error(`Malformed '${scope}' tag in project '${project.name}', expected '${scope}:<value>', found '${tag}'`);
                }
            }
        }
    }
    throw new Error(`Project '${project.name}' has a missing '${scope}' tag in project. Ensure this is set correctly.`);
}
exports.getFirebaseScopeFromTag = getFirebaseScopeFromTag;
function updateFirebaseProjectNameTag(tree, project) {
    const appNameTag = getFirebaseScopeFromTag(project, 'firebase:name');
    const newAppNameTag = `firebase:name:${project.name}`;
    project.tags[appNameTag.tagIndex] = newAppNameTag;
    (0, devkit_1.updateProjectConfiguration)(tree, project.name, project);
}
exports.updateFirebaseProjectNameTag = updateFirebaseProjectNameTag;
//# sourceMappingURL=tags.js.map