"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.checkNxVersion = exports.workspaceNxVersion = void 0;
const devkit_1 = require("@nx/devkit");
const nx_firebase_versions_1 = require("../__generated__/nx-firebase-versions");
function readNxWorkspaceVersion() {
    // Check the runtime Nx version being used by the current workspace
    const semVerRegEx = /[~^]?([\dvx*]+(?:[-.](?:[\dx*]+|alpha|beta))*)/g;
    const workspacePackage = (0, devkit_1.readJsonFile)(`${devkit_1.workspaceRoot}/package.json`);
    const workspaceNxPackageVersion = workspacePackage.devDependencies['nx'];
    if (workspaceNxPackageVersion) {
        const workspaceNxVersion = workspaceNxPackageVersion.match(semVerRegEx);
        if (workspaceNxVersion.length) {
            const semver = workspaceNxVersion[0].split('.');
            const major = parseInt(semver[0]);
            const minor = parseInt(semver[1]);
            const patch = parseInt(semver[2]);
            return {
                version: workspaceNxVersion[0],
                versionCode: major * 10000 + minor * 100 + patch,
                major,
                minor,
            };
        }
    }
    return undefined;
}
// determine the Nx version being used by the host workspace
exports.workspaceNxVersion = readNxWorkspaceVersion();
function checkNxVersion() {
    // Declare target version of Nx that the plugin is currently compatible with
    const pluginNxVersionMajor = parseInt(nx_firebase_versions_1.packageVersions.nx.split('.')[0]);
    if (exports.workspaceNxVersion) {
        if (exports.workspaceNxVersion.major !== pluginNxVersionMajor) {
            devkit_1.logger.warn(`WARNING: This version of @simondotm/nx-firebase plugin was built for Nx version ^${nx_firebase_versions_1.packageVersions.nx}, and may not be compatible with your version of Nx (${exports.workspaceNxVersion.version})`);
        }
    }
    else {
        devkit_1.logger.warn(`@simondotm/nx-firebase plugin could not determine your version of Nx. It may not be compatible.`);
    }
}
exports.checkNxVersion = checkNxVersion;
//# sourceMappingURL=workspace.js.map